# compas_ags

![build](https://github.com/blockresearchgroup/compas_ags/workflows/build/badge.svg)

[![GitHub - License](https://img.shields.io/github/license/blockresearchgroup/compas_ags.svg)](https://github.com/blockresearchgroup/compas_ags)

**compas_ags** is a COMPAS package for Computational Graphic Statics.
It combines implementations of the following papers:

* Algebraic Graph Statics
* Bi-directional Algebraic Graph Statics
* Load-path optimisation of funcicular networks

See "[Publications](https://blockresearchgroup.github.io/compas_ags/latest/publications.html)" for more info.

## Getting Started

Have a look at the "Getting Started" instructions in the docs: <https://blockresearchgroup.github.io/compas_ags/latest/gettingstarted.html>.

## First Steps

A good place to start exploring AGS through `compas_ags` are the [examples](https://blockresearchgroup.github.io/compas_ags/latest/examples.html).

## Questions and feedback

For questions and feedback, read through or post something in the [compas_ags category](https://forum.compas-framework.org/c/compas-ags) of the COMPAS forum.

## Issue tracker

If you find a bug, please help us solve it by [filing a report](https://github.com/blockresearchgroup/compas_ags/issues).

## Contributing

If you want to contribute, check out our [developer guidelines](https://blockresearchgroup.github.io/compas_ags/latest/devguide.html).

## License

`compas_ags` is licensed under the MIT License. See [LICENSE](https://github.com/blockresearchgroup/compas_ags/blob/master/LICENSE), for more information.
